package cn.pluss.platform.mapper;

import java.util.List;
import java.util.Map;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;
import cn.pluss.platform.entity.ActivityActivate;

@Mapper
public interface ActivityActivateMapper extends BaseMapper<ActivityActivate> {

    ActivityActivate queryActivityActivate(ActivityActivate activityActivate);

    List<ActivityActivate> queryActivityActivateList(ActivityActivate activityActivate);

    void updateActivityActivate(ActivityActivate activityActivate);
    
    List<ActivityActivate> queryActivityActivatePage(Map map);

    List<ActivityActivate> queryNoActivityActivatePage(Map map);

    Integer queryActivityActivatePageCount(Map map);

    Integer queryNoActivityActivatePageCount(Map map);

    void saveActivityActivateBatch(List<ActivityActivate>  activityActivateList);

    List<Map<String, Object>> getNewestActivityJoin(String storeId);
}

